==> nextcloud-app-bookmarks-1%3A3.0.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/uk.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Закладки",
    "No file provided for import" : "Відсутній файл для імпорту",
    "Unsupported file type for import" : "Цей тип файлу не підтримується",
    "Details" : "Деталі",
    "Rename" : "Перейменувати",
    "Move" : "Перемістити",
    "Delete" : "Видалити",
    "Save" : "Зберегти",
    "New folder" : "Нова тека",
    "Grid view" : "Упорядкування у формі сітки",
    "List view" : "Упорядкування у формі списку",
    "Create" : "Створити",
    "Cancel" : "Скасувати",
    "Public" : "Публічне",
    "Import" : "Імпорт",
    "Export" : "Експорт",
    "Recently added" : "Нещодавно додані",
    "Alphabetically" : "За алфавітом",
    "Last modified" : "Останні зміни",
    "Clear data" : "Очистити дані",
    "URL" : "URL-адреса",
    "Tags" : "Позначки",
    "Notes" : "Нотатки",
    "Sharing" : "Поділитись",
    "Owner" : "Власник",
    "Share link" : "Поширити посилання",
    "Copy link" : "Скопіювати посилання",
    "Allow editing" : "Дозволити редагування",
    "Link copied" : "Посилання скопійовано",
    "Select" : "Вибрати",
    "Privacy" : "Конфіденційність",
    "Add a bookmark" : "Додати закладку",
    "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
    "Title" : "Назва",
    "Link" : "Посилання"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-bookmarks-1%3A3.2.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/uk.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Закладки",
    "No file provided for import" : "Відсутній файл для імпорту",
    "Unsupported file type for import" : "Цей тип файлу не підтримується",
    "Details" : "Деталі",
    "Rename" : "Перейменувати",
    "Move" : "Перемістити",
    "Delete" : "Вилучити",
    "Save" : "Зберегти",
    "New folder" : "Нова тека",
    "Grid view" : "Упорядкування у формі сітки",
    "List view" : "Упорядкування у формі списку",
    "Create" : "Створити",
    "Cancel" : "Скасувати",
    "Public" : "Публічне",
    "Import" : "Імпорт",
    "Export" : "Експорт",
    "Recently added" : "Нещодавно додані",
    "Alphabetically" : "За алфавітом",
    "Last modified" : "Останні зміни",
    "Clear data" : "Очистити дані",
    "URL" : "URL-адреса",
    "Tags" : "Позначки",
    "Notes" : "Нотатки",
    "Sharing" : "Поділитись",
    "Owner" : "Власник",
    "Select a user or group" : "Виберіть користувача або групу",
    "Share link" : "Поширити посилання",
    "Copy link" : "Скопіювати посилання",
    "Allow editing" : "Дозволити редагування",
    "Link copied" : "Посилання скопійовано",
    "Select" : "Вибрати",
    "Privacy" : "Конфіденційність",
    "Failed to save settings" : "Неможливо зберегти налаштування",
    "Add a bookmark" : "Додати закладку",
    "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
    "Title" : "Назва",
    "Link" : "Посилання",
    "Folder" : "Папка"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
